@@ -38,13 +38,13 @@ tab <- tab[order(tab$population),]
           # bt defines the times of bootstrap-resampling.
 allelefreq(tab)  
   
-Empirical.values <- calc(allelefrequency,sample.sizes,x)
+Empirical.values <- calc(DEMEtics.env$allelefrequency,DEMEtics.env$sample.sizes,x)
 
           # Dest.Chao values are calculated for each locus as well as
           # averaged over all loci from the empirical data table.
 
-locus.empirical <- values[[1]]
-means.empirical <- values[[2]]  
+locus.empirical <- DEMEtics.env$values[[1]]
+means.empirical <- DEMEtics.env$values[[2]]  
   
 
 tab2 <- split(tab,tab$locus)
@@ -67,7 +67,7 @@ LocusMeans1 <- lapply(repetition,function(y) locus.means.calc(repetition.val=y,t
 locus <- lapply(LocusMeans1,function(x) x[[1]])
 means <- sapply(LocusMeans1,function(x) x[[2]])
 
-assign("means",means,pos = ".GlobalEnv")
+assign("means",means,pos = DEMEtics.env)
 
           # The list "Dest.locus" and the vector "Dest.means" are both saved
           # according to their names in the workspace of R in order to be
@@ -88,7 +88,7 @@ loci <- do.call(rbind,locus)
           # The Dest values for the several loci are combined in a single
           # data frame.
           
-assign("loci",loci,pos = ".GlobalEnv") 
+assign("loci",loci,pos = DEMEtics.env) 
 
           # The data.frame "Dest.loci" is saved with its according name
           # in the workspace of R in order to be available for further calculations.         
@@ -108,7 +108,7 @@ colnames(critical.value.loci)<-c("0.95.conf.int.lower","0.95.conf.int.upper")
 confidence.limits<-list(critical.value.loci,critical.values.means)
 names(confidence.limits)<-c("confidence.limits.per.locus","confidence.limit.over.all.loci")
 invisible(confidence.limits)
-assign("confidence.limits",confidence.limits,pos = ".GlobalEnv")
+assign("confidence.limits",confidence.limits,pos = DEMEtics.env)
 
           # The end result of the bootstrapping is the list called 
           # 'confidence.limits' that contains the significance levels
